@@ -11,15 +11,15 @@ class GF7Satellite(BaseSatellite):
         预解析
         """
         if self.sensor_id == 'APD' or self.sensor_id == 'DLC':
-            member_image_name = "{}_FP1-1.jpg".format(self.base_name)
-            member_xml_name = "{}.xml".format(self.base_name)
+            self.image_name = "{}_FP1-1.jpg".format(self.base_name)
+            self.xml_name = "{}.xml".format(self.base_name)
         else:
             print('Pre Parse None')
             return
-        member_image = tar.getmember(member_image_name)
+        member_image = tar.getmember(self.image_name)
         # image 为解压后的图片文件
-        self.image = tar.extractfile(member_image)
-        member_xml = tar.getmember(member_xml_name)
+        self.image = tar.extractfile(member_image).read()
+        member_xml = tar.getmember(self.xml_name)
         # data 为解压并解析后的字典数据
         self.data = self.xmltodict(
             tar.extractfile(member_xml).read())
